@@ -486,7 +486,7 @@ class TestJobsCreate(object):
         "--isPreemptible", "True",
         "--projectId", "some_project_id",
         "--isPublic", "True",
-        "--jobEnv", '{"key":"val"}',
+        "--envVars", '{"key":"val"}',
         "--machineType", "K80",
         "--name", "some_name",
         "--nodeAttrs", '{"key":"val"}',
@@ -527,7 +527,7 @@ class TestJobsCreate(object):
         "registryTarget": "some_registry_target",
         "isPublic": True,
         "workspaceFileName": "s3://some-path",
-        "jobEnv": {"key": "val"},
+        "envVars": '{"key": "val"}',
         "useDockerfile": True,
         "name": "some_name",
         "relDockerfilePath": "some dockerfile path",
